# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import service_pb2 as proto_dot_service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in proto/service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class JsonServiceStub(object):
    """Service definition for handling JSON data processing
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProcessJson = channel.unary_unary(
                '/jsonservice.JsonService/ProcessJson',
                request_serializer=proto_dot_service__pb2.JsonRequest.SerializeToString,
                response_deserializer=proto_dot_service__pb2.JsonResponse.FromString,
                _registered_method=True)
        self.StreamJson = channel.stream_stream(
                '/jsonservice.JsonService/StreamJson',
                request_serializer=proto_dot_service__pb2.JsonRequest.SerializeToString,
                response_deserializer=proto_dot_service__pb2.JsonResponse.FromString,
                _registered_method=True)


class JsonServiceServicer(object):
    """Service definition for handling JSON data processing
    """

    def ProcessJson(self, request, context):
        """ProcessJson processes a single JSON request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamJson(self, request_iterator, context):
        """StreamJson handles continuous JSON data processing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JsonServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ProcessJson': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessJson,
                    request_deserializer=proto_dot_service__pb2.JsonRequest.FromString,
                    response_serializer=proto_dot_service__pb2.JsonResponse.SerializeToString,
            ),
            'StreamJson': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamJson,
                    request_deserializer=proto_dot_service__pb2.JsonRequest.FromString,
                    response_serializer=proto_dot_service__pb2.JsonResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jsonservice.JsonService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('jsonservice.JsonService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class JsonService(object):
    """Service definition for handling JSON data processing
    """

    @staticmethod
    def ProcessJson(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/jsonservice.JsonService/ProcessJson',
            proto_dot_service__pb2.JsonRequest.SerializeToString,
            proto_dot_service__pb2.JsonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamJson(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/jsonservice.JsonService/StreamJson',
            proto_dot_service__pb2.JsonRequest.SerializeToString,
            proto_dot_service__pb2.JsonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
