# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13proto/service.proto\x12\x0bjsonservice\"\xb2\x01\n\x0bJsonRequest\x12\x11\n\tjson_data\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x38\n\x08metadata\x18\x04 \x03(\x0b\x32&.jsonservice.JsonRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd2\x01\n\x0cJsonResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bresult_json\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\r\n\x05\x65rror\x18\x05 \x01(\t\x12\x39\n\x08metadata\x18\x06 \x03(\x0b\x32\'.jsonservice.JsonResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x9c\x01\n\x0bJsonService\x12\x44\n\x0bProcessJson\x12\x18.jsonservice.JsonRequest\x1a\x19.jsonservice.JsonResponse\"\x00\x12G\n\nStreamJson\x12\x18.jsonservice.JsonRequest\x1a\x19.jsonservice.JsonResponse\"\x00(\x01\x30\x01\x42\x0fZ\r./jsonserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\r./jsonservice'
  _globals['_JSONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_JSONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_JSONRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_JSONRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_JSONREQUEST']._serialized_start=37
  _globals['_JSONREQUEST']._serialized_end=215
  _globals['_JSONREQUEST_METADATAENTRY']._serialized_start=168
  _globals['_JSONREQUEST_METADATAENTRY']._serialized_end=215
  _globals['_JSONRESPONSE']._serialized_start=218
  _globals['_JSONRESPONSE']._serialized_end=428
  _globals['_JSONRESPONSE_METADATAENTRY']._serialized_start=168
  _globals['_JSONRESPONSE_METADATAENTRY']._serialized_end=215
  _globals['_JSONSERVICE']._serialized_start=431
  _globals['_JSONSERVICE']._serialized_end=587
# @@protoc_insertion_point(module_scope)
